``nbclassic`` pack - Classic notebook
=====================================

The ``nbclassic`` pack installs and enables the classic Jupyter Notebook (v6.x) served via the
`nbclassic package <https://github.com/jupyter/nbclassic>`_.

To enable the pack, add it to the ``packs`` key as follows:

.. code:: yaml

    packs:
      - name: nbclassic

The pack does not have any configuration options.
